Nagios plugins for dCache
=========================

A collection of nagios plugins to monitor a [dCache][] storage.

How to install
--------------

    pip install dcache-nagios-plugins


[dCache]: https://www.dcache.org
